Type Alias Moment

pub type Moment<T> = <T as Config>::Moment;
Wall-clock timestamp type used by Finalized storage.

An alias for the timestamp type provided by [pallet_timestamp] for the given runtime.

It is used exclusively for time-based finality evaluation (for example, measuring how long a value has survived), and is not used for ordering, counting, or block-based logic.

Block-scoped semantics (such as observation counts) are expressed separately via [BlockNumberFor].