pub enum Confidence<Value>where
Value: Portable,{
Safe(Value),
Risky(Value),
Unsafe(Value),
}Expand description
Confidence signal derived for a value evaluated by Finalized storage.
This enum represents the outcome of applying a FinalizedPolicy to an
observed value, based on elapsed time and block-scoped observations.
It expresses a signal of stability, not on-chain finality and not a definitive statement of truth.
Variants
Safe(Value)
A strong confidence signal.
The value has:
- survived the configured finality time window, and
- been observed across enough distinct blocks.
This signal suggests that the value is likely stable and that irreversible or non-recoverable actions may be reasonable.
Risky(Value)
A weak confidence signal.
The value has survived the finality time window, but has not yet accumulated enough block-scoped observations.
This signal suggests that only optimistic or recoverable actions should be considered.
Unsafe(Value)
A negative confidence signal.
The value exists, but the finality time window has not elapsed yet.
This signal suggests that no action-reversible or irreversible- should be taken at this stage.