pub trait SubstrateOffchainStorage { }Expand description
Marker trait for Substrate offchain storage kinds (backends).
Used exclusively for compile-time specialization and trait bounds. This trait has no methods and implies no behavior.
Implementors
impl<Context, Value, Routine> SubstrateOffchainStorage for Persistent<Context, Value, Routine>
Default backend marker implementation for all valid Persistent specializations.
This blanket implementation marks every well-formed Persistent<Context, Value, Routine>
type as a supported Substrate offchain storage backend.
impl<Context, Value, Routine, Handler> SubstrateOffchainStorage for ForkAware<Context, Value, Routine, Handler>where
Context: Config,
Value: Portable,
Routine: Routines<BlockNumberFor<Context>>,
Handler: ForksHandler<Context, ForkLocalDepot>,
Default backend marker implementation for all valid ForkAware specializations.
This blanket implementation marks every well-formed ForkAware<Context, Value, Routine>
type as a supported Substrate offchain storage backend.